==> HTML-WikiConverter-DokuWikiFCK-0.27.tgz: fckg/action/save.php <==
<?php
if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../../../').'/');
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'action.php');

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Pierre Spring <pierre.spring@liip.ch>
 */

class action_plugin_fckg_save extends DokuWiki_Action_Plugin {
    /**
     * Constructor
     */
    function action_plugin_fckg_save(){
    }

    function getInfo() {
        return array(
            'author' => 'Myron Turner',
            'email'  => 'turnermm02@shaw.ca',
            'date'   => '2008-Aug-30',
            'name'   => 'fckg_save',
            'desc'   => 'Save Plugin for the DokuwikiFCK',
            'url'    => 'http://www.mturner.org');
    }

    function register(&$controller) {
        $controller->register_hook('DOKUWIKI_STARTED', 'BEFORE', $this, 'fckg_save_preprocess');
    }

    function fckg_save_preprocess(&$event){
        global $ACT;
        if (!isset($_REQUEST['fckg']) || ! is_array($ACT) || !(isset($ACT['save']) || isset($ACT['preview']))) return;
        $dir = dirname(__FILE__);
        $path = realpath($dir);

        $browser="IE5";
        $saveFCK= $path . '/saveFCK.pl';
        $host = 'plato';
        $group = 'ANY';

        if(!file_exists ($saveFCK)) {
           $saveFCK='saveFCK.pl';
        }
        else {
           $saveFCK="perl " .  $saveFCK;
        }

        global $TEXT;
        if (!$TEXT) return;

        // transform html back into wiki syntax


    if(isset($_SERVER) && isset($_SERVER['HTTP_USER_AGENT'])) {
       $browser=$_SERVER['HTTP_USER_AGENT'];
       $host = escapeshellarg($_SERVER['HTTP_HOST']); 
    }

       $browser = escapeshellarg($browser); 
       $group = escapeshellarg($group);   
       $dialect = "DokuWikiFCK";

       if($this->is_middot_user()) {
           $dialect = "DokuWikiFCKN";
       }
//echo "Dialect=$dialect<br>";

       $TEXT = shell_exec('echo ' . escapeshellarg($TEXT) . ' | ' . $saveFCK .
        ' --base-uri=' . $host . 
        ' --group=' . $group .
        ' --dialect=' . $dialect .
        ' --browser=' . $browser );  
        
      
        $TEXT = preg_replace('/(({{)|(\[\[))\//', '$1http://'.$_SERVER['HTTP_HOST'].'/', $TEXT);
        $TEXT = @html_entity_decode($TEXT, ENT_NOQUOTES, 'UTF-8');
    
    }

    function is_middot_user() {
        global $INFO;
        $users = $this->getConf('middot');
        $users = trim($users);

        $user_groups = $INFO['userinfo']['grps'];


        $middot_groups = explode(',',$users);
        foreach($middot_groups as $group) {
                  $group = trim($group);
                  if(in_array ($group, $user_groups) ) {        
                       return true;
                  }
        }  
        
       return false;  
    }


} //end of action class
?>

==> HTML-WikiConverter-DokuWikiFCK-0.31.tgz: fckg/action/save.php <==
<?php
if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../../../').'/');
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'action.php');

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Pierre Spring <pierre.spring@liip.ch>
 */

class action_plugin_fckg_save extends DokuWiki_Action_Plugin {
    /**
     * Constructor
     */
    function action_plugin_fckg_save(){
    }

    function getInfo() {
        return array(
            'author' => 'Myron Turner',
            'email'  => 'turnermm02@shaw.ca',
            'date'   => '2008-Aug-30',
            'name'   => 'fckg_save',
            'desc'   => 'Save Plugin for the DokuwikiFCK',
            'url'    => 'http://www.mturner.org');
    }

    function register(&$controller) {
        $controller->register_hook('DOKUWIKI_STARTED', 'BEFORE', $this, 'fckg_save_preprocess');
    }

    function fckg_save_preprocess(&$event){
        global $ACT;
        if (!isset($_REQUEST['fckg']) || ! is_array($ACT) || !(isset($ACT['save']) || isset($ACT['preview']))) return;
        $dir = dirname(__FILE__);
        $path = realpath($dir);

        $browser="IE5";
        $saveFCK= $path . '/saveFCK.pl';
        $host = 'plato';
        $group = 'ANY';

        if(!file_exists ($saveFCK)) {
           $saveFCK='saveFCK.pl';
        }
        else {
           $saveFCK="perl " .  $saveFCK;
        }

        global $TEXT;
        if (!$TEXT) return;

        // transform html back into wiki syntax


    if(isset($_SERVER) && isset($_SERVER['HTTP_USER_AGENT'])) {
       $browser=$_SERVER['HTTP_USER_AGENT'];
       $host = escapeshellarg($_SERVER['HTTP_HOST']); 
    }

       $browser = escapeshellarg($browser); 
       $group = escapeshellarg($group);   
       $dialect = "DokuWikiFCK";

       if($this->is_middot_user()) {
           $dialect = "DokuWikiFCKN";
       }


$big_files = $this->getConf('big_files');
$size = $this->getConf('big_file_sz');
$strL = strlen($TEXT);

if($big_files && $strL > $size) {
    $tmpfname = tempnam(DOKU_INC . 'data/tmp', "dwiki");
    $handle = fopen($tmpfname, "w");
    fwrite($handle, $TEXT);
    fclose($handle);
    $lockfile = $tmpfname . ".lock";
    $handle = fopen($lockfile, "w");
    fwrite($handle, $lockfile);
    fclose($handle);
    shell_exec( $saveFCK .      
        ' --file=' . $tmpfname .
        ' --base-uri=' . $host . 
        ' --group=' . $group .
        ' --dialect=' . $dialect .
        ' --browser=' . $browser );

   $count = 0;
   $secs = $this->getConf('big_file_tm');  
   while(file_exists($lockfile)) {
     $count++;
     if($count == $secs) {
        unlink($tmpfname);
        unlink($lockfile);
        $this->get_original_text();
        msg('Attempt to write large file timed out; edits have not been saved.', -1);
        return;
     }
     sleep(1);         
   }
 
     
      $TEXT = file_get_contents ($tmpfname);  
      unlink($tmpfname); 
     
  
  
}

else {
       $TEXT = shell_exec('echo ' . escapeshellarg($TEXT) . ' | ' . $saveFCK .      
        ' --base-uri=' . $host . 
        ' --group=' . $group .
        ' --dialect=' . $dialect .
        ' --browser=' . $browser );  
}
      
        $TEXT = preg_replace('/(({{)|(\[\[))\//', '$1http://'.$_SERVER['HTTP_HOST'].'/', $TEXT);
        $TEXT = @html_entity_decode($TEXT, ENT_NOQUOTES, 'UTF-8');
    
    }

    function get_original_text() {
        global $TEXT;
        $namespace = $_REQUEST[id];
        $dw_file = DOKU_INC.'data/pages/' . str_replace(':','/',$namespace) . '.txt'; 
        $TEXT = file_get_contents ($dw_file);  
    }

    function is_middot_user() {
        global $INFO;
        $users = $this->getConf('middot');
        $users = trim($users);

        if(!isset($INFO['userinfo'])) {
               return false;
        }

        $user_groups = $INFO['userinfo']['grps'];


        $middot_groups = explode(',',$users);
        foreach($middot_groups as $group) {
                  $group = trim($group);
                  if(in_array ($group, $user_groups) ) {        
                       return true;
                  }
        }  
        
       return false;  
    }


} //end of action class
?>
